import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range(['darkred', '#f1f90c'])

const radiusScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range([60, 35]);

const xPosition = (d,i) => i * 150 + 150;

export const fruitBowl = (selection, props) => {
  const { fruits,
         	height,
         	setSelectedFruit,
    			selectedFruit
        } = props;
  
  const bowl = selection.selectAll('rect')
    .data([null])
    .enter().append('rect')
      .attr('y', 110)
      .attr('width', 920 + 39)
      .attr('height', 300)
      .attr('rx', 300 / 2);
  
  const groups = selection.selectAll('g')
    .data(fruits, d => d.id);
  const groupsEnter = groups.enter().append('g');
  groupsEnter
    .merge(groups)
      .attr('transform', (d, i) =>
        `translate(${i * 150 + 150},${height / 2})`
      ); 
  groups.exit() 
      .attr('r', 0)
    .remove();
    
  const circles = selection.selectAll('circle')
    .data(fruits, d => d.id);
  circles
    .enter().append('circle')
      .attr('cx', xPosition)
      .attr('cy', height / 2)
      .attr('r', 0)
    .merge(circles)
      .attr('fill', d => colorScale(d.type))
  		.attr('stroke-width', 5)
      .attr('stroke', d =>
        d.id === selectedFruit
          ? 'black'
          : 'none'
      )
      .on('mouseover', d => setSelectedFruit(d.id))
      .on('mouseout', () => setSelectedFruit(null))
    .transition().duration(1000)
      .attr('cx', xPosition)
      .attr('r', d => radiusScale(d.type));
  circles.exit()
    .transition().duration(1000)
      .attr('r', 0)
    .remove();
  
  groupsEnter.append('text')
    .merge(groups.select('text'))
      .text(d => d.type)
      .attr('y', 120);
}